# Track data

Use the LaminDB instance to track your local files, cloud files or in-memory objects via {class}`~lamindb.File`.

**Jump to:**

- {doc}`/guide/files`
- {doc}`/guide/memory`
- {doc}`/guide/add-delete`
- {doc}`/guide/run`
- {doc}`/guide/existing`
- {doc}`/guide/folder`

```{toctree}
:hidden:
:maxdepth: 1

files
memory
add-delete
run
existing
folder
```
